@@ -6,21 +6,50 @@ from ray.rllib.utils import override
 from raylab.policy import TorchPolicy
 from raylab.policy.action_dist import WrapDeterministicPolicy
 from raylab.policy.losses import ClippedDoubleQLearning
+from raylab.policy.modules.critic.q_value import QValue
+from raylab.policy.modules.critic.q_value import QValueEnsemble
 from raylab.pytorch.nn.utils import update_polyak
 from raylab.pytorch.optim import build_optimizer
 
 
+class NAFValue(QValue):
+    """Wrapper around NAF."""
+
+    # pylint:disable=super-init-not-called,non-parent-init-called
+    def __init__(self, naf: nn.Module):
+        nn.Module.__init__(self)
+        self.naf = naf
+
+    def forward(self, obs, action):
+        return self.naf(obs, action)
+
+
+class TargetNAFValue(QValue):
+    """Wrapper around NAF's state-value function."""
+
+    # pylint:disable=super-init-not-called,non-parent-init-called
+    def __init__(self, naf_value: nn.Module):
+        nn.Module.__init__(self)
+        self.naf_value = naf_value
+
+    def forward(self, obs, action):
+        return self.naf_value(obs)
+
+
 class NAFTorchPolicy(TorchPolicy):
     """Normalized Advantage Function policy in Pytorch to use with RLlib."""
 
-    # pylint: disable=abstract-method
+    # pylint:disable=abstract-method
     dist_class = WrapDeterministicPolicy
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        target_critics = [lambda s, _, v=v: v(s) for v in self.module.target_vcritics]
+        critics = QValueEnsemble([NAFValue(n) for n in self.module.critics])
+        target_critics = QValueEnsemble(
+            [TargetNAFValue(v) for v in self.module.target_vcritics]
+        )
         self.loss_fn = ClippedDoubleQLearning(
-            self.module.critics, target_critics, actor=lambda _: None,
+            critics, target_critics, actor=lambda _: None
         )
         self.loss_fn.gamma = self.config["gamma"]
 
@@ -28,7 +57,7 @@ class NAFTorchPolicy(TorchPolicy):
     @override(TorchPolicy)
     def get_default_config():
         """Return the default config for NAF."""
-        # pylint: disable=cyclic-import,protected-access
+        # pylint:disable=cyclic-import,protected-access
         from raylab.agents.naf import NAFTrainer
 
         return NAFTrainer._default_config
